#! python3
#mogl_groups.py
#A tool to process output of appointments_training_reports.py into group lists
#Licence: GPL-3.0-or-later
#Written by Stuart Griffiths, stuart.griffiths@birminghamscouts.org.uk
#Started 25/09/2022
#Version:0.2
#Released: 25/09/2022
#Status: Working
#Inputs: CSV
#Outputs: multiple CSV 
#Next Steps: 
#Issues:  
#Background IP: https://automatetheboringstuff.com/, Chapter 16

#Notes - CSV Column Numbers
#Membership_Number = 0
#Known_Name = 1
#Surname = 2
#Email = 3
#Telephone = 4
#Member_Role = 5
#Line_Manager = 6
#Scout_Group = 7
#District = 8
#Safety = 9
#Safeguarding = 10
#First Aid = 11

#Libraries
import os #Enables file IO
from pathlib import Path #to work out current working directory
import csv #required to handle csv files

#1. Set up Output files

CVS_group_list = ['81st Birmingham (1st West Heath)',
'96th Birmingham South (1st Grove)',
'192nd Birmingham (2nd Acocks Green)',
'24th Birmingham (Manor Farm)',
'254th Birmingham (St Peters Church)',
'89th Birmingham (1st Hall Green)',
'220th Birmingham (St Agnes)',
'260th Birmingham',
'100th Birmingham (1st Bournville)',
'219th Birmingham',
'198th Birmingham (1st St.Nicolas)',
'232nd Birmingham (Acocks Green)',
'258th Birmingham St Annes West Heath',
'29th Birmingham (Selly Park)',
'279th Birmingham Hall Green Parish',
'304th Birmingham MAB',
'148th Birmingham (St Dunstans)',
'325th Birmingham (Billesley) Scout Group']

#CSV files

#CVS
_81_late_mandatory_file = open('81_late_mandatory_training.csv', 'w', newline='')
_81_late_mandatory = csv.writer(_81_late_mandatory_file)
_81_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_81_due_mandatory_file = open('81_due_mandatory_training.csv', 'w', newline='')
_81_due_mandatory = csv.writer(_81_due_mandatory_file)
_81_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_96_late_mandatory_file = open('96_late_mandatory_training.csv', 'w', newline='')
_96_late_mandatory = csv.writer(_96_late_mandatory_file)
_96_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_96_due_mandatory_file = open('96_due_mandatory_training.csv', 'w', newline='')
_96_due_mandatory = csv.writer(_96_due_mandatory_file)
_96_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_192_late_mandatory_file = open('192_late_mandatory_training.csv', 'w', newline='')
_192_late_mandatory = csv.writer(_192_late_mandatory_file)
_192_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_192_due_mandatory_file = open('192_due_mandatory_training.csv', 'w', newline='')
_192_due_mandatory = csv.writer(_192_due_mandatory_file)
_192_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_24_late_mandatory_file = open('24_late_mandatory_training.csv', 'w', newline='')
_24_late_mandatory = csv.writer(_24_late_mandatory_file)
_24_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_24_due_mandatory_file = open('24_due_mandatory_training.csv', 'w', newline='')
_24_due_mandatory = csv.writer(_24_due_mandatory_file)
_24_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_254_late_mandatory_file = open('254_late_mandatory_training.csv', 'w', newline='')
_254_late_mandatory = csv.writer(_254_late_mandatory_file)
_254_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_254_due_mandatory_file = open('254_due_mandatory_training.csv', 'w', newline='')
_254_due_mandatory = csv.writer(_254_due_mandatory_file)
_254_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_89_late_mandatory_file = open('89_late_mandatory_training.csv', 'w', newline='')
_89_late_mandatory = csv.writer(_89_late_mandatory_file)
_89_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_89_due_mandatory_file = open('89_due_mandatory_training.csv', 'w', newline='')
_89_due_mandatory = csv.writer(_89_due_mandatory_file)
_89_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_220_late_mandatory_file = open('220_late_mandatory_training.csv', 'w', newline='')
_220_late_mandatory = csv.writer(_220_late_mandatory_file)
_220_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_220_due_mandatory_file = open('220_due_mandatory_training.csv', 'w', newline='')
_220_due_mandatory = csv.writer(_220_due_mandatory_file)
_220_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_260_late_mandatory_file = open('260_late_mandatory_training.csv', 'w', newline='')
_260_late_mandatory = csv.writer(_260_late_mandatory_file)
_260_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_260_due_mandatory_file = open('260_due_mandatory_training.csv', 'w', newline='')
_260_due_mandatory = csv.writer(_260_due_mandatory_file)
_260_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_100_late_mandatory_file = open('100_late_mandatory_training.csv', 'w', newline='')
_100_late_mandatory = csv.writer(_100_late_mandatory_file)
_100_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_100_due_mandatory_file = open('100_due_mandatory_training.csv', 'w', newline='')
_100_due_mandatory = csv.writer(_100_due_mandatory_file)
_100_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_219_late_mandatory_file = open('219_late_mandatory_training.csv', 'w', newline='')
_219_late_mandatory = csv.writer(_219_late_mandatory_file)
_219_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_219_due_mandatory_file = open('219_due_mandatory_training.csv', 'w', newline='')
_219_due_mandatory = csv.writer(_219_due_mandatory_file)
_219_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_198_late_mandatory_file = open('198_late_mandatory_training.csv', 'w', newline='')
_198_late_mandatory = csv.writer(_198_late_mandatory_file)
_198_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_198_due_mandatory_file = open('198_due_mandatory_training.csv', 'w', newline='')
_198_due_mandatory = csv.writer(_198_due_mandatory_file)
_198_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_232_late_mandatory_file = open('232_late_mandatory_training.csv', 'w', newline='')
_232_late_mandatory = csv.writer(_232_late_mandatory_file)
_232_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_232_due_mandatory_file = open('232_due_mandatory_training.csv', 'w', newline='')
_232_due_mandatory = csv.writer(_232_due_mandatory_file)
_232_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_258_late_mandatory_file = open('258_late_mandatory_training.csv', 'w', newline='')
_258_late_mandatory = csv.writer(_258_late_mandatory_file)
_258_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_258_due_mandatory_file = open('258_due_mandatory_training.csv', 'w', newline='')
_258_due_mandatory = csv.writer(_258_due_mandatory_file)
_258_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_29_late_mandatory_file = open('29_late_mandatory_training.csv', 'w', newline='')
_29_late_mandatory = csv.writer(_29_late_mandatory_file)
_29_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_29_due_mandatory_file = open('29_due_mandatory_training.csv', 'w', newline='')
_29_due_mandatory = csv.writer(_29_due_mandatory_file)
_29_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_279_late_mandatory_file = open('279_late_mandatory_training.csv', 'w', newline='')
_279_late_mandatory = csv.writer(_279_late_mandatory_file)
_279_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_279_due_mandatory_file = open('279_due_mandatory_training.csv', 'w', newline='')
_279_due_mandatory = csv.writer(_279_due_mandatory_file)
_279_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_304_late_mandatory_file = open('304_late_mandatory_training.csv', 'w', newline='')
_304_late_mandatory = csv.writer(_304_late_mandatory_file)
_304_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_304_due_mandatory_file = open('304_due_mandatory_training.csv', 'w', newline='')
_304_due_mandatory = csv.writer(_304_due_mandatory_file)
_304_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_148_late_mandatory_file = open('148_late_mandatory_training.csv', 'w', newline='')
_148_late_mandatory = csv.writer(_148_late_mandatory_file)
_148_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_148_due_mandatory_file = open('148_due_mandatory_training.csv', 'w', newline='')
_148_due_mandatory = csv.writer(_148_due_mandatory_file)
_148_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_325_late_mandatory_file = open('325_late_mandatory_training.csv', 'w', newline='')
_325_late_mandatory = csv.writer(_325_late_mandatory_file)
_325_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_325_due_mandatory_file = open('325_due_mandatory_training.csv', 'w', newline='')
_325_due_mandatory = csv.writer(_325_due_mandatory_file)
_325_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#Rea

_74_late_mandatory_file = open('74_late_mandatory_training.csv', 'w', newline='')
_74_late_mandatory = csv.writer(_74_late_mandatory_file)
_74_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_74_due_mandatory_file = open('74_due_mandatory_training.csv', 'w', newline='')
_74_due_mandatory = csv.writer(_74_due_mandatory_file)
_74_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_191_late_mandatory_file = open('191_late_mandatory_training.csv', 'w', newline='')
_191_late_mandatory = csv.writer(_191_late_mandatory_file)
_191_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_191_due_mandatory_file = open('191_due_mandatory_training.csv', 'w', newline='')
_191_due_mandatory = csv.writer(_191_due_mandatory_file)
_191_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_145_late_mandatory_file = open('145_late_mandatory_training.csv', 'w', newline='')
_145_late_mandatory = csv.writer(_145_late_mandatory_file)
_145_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_145_due_mandatory_file = open('145_due_mandatory_training.csv', 'w', newline='')
_145_due_mandatory = csv.writer(_145_due_mandatory_file)
_145_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_108_late_mandatory_file = open('108_late_mandatory_training.csv', 'w', newline='')
_108_late_mandatory = csv.writer(_108_late_mandatory_file)
_108_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_108_due_mandatory_file = open('108_due_mandatory_training.csv', 'w', newline='')
_108_due_mandatory = csv.writer(_108_due_mandatory_file)
_108_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_169_late_mandatory_file = open('169_late_mandatory_training.csv', 'w', newline='')
_169_late_mandatory = csv.writer(_169_late_mandatory_file)
_169_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_169_due_mandatory_file = open('169_due_mandatory_training.csv', 'w', newline='')
_169_due_mandatory = csv.writer(_169_due_mandatory_file)
_169_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_293_late_mandatory_file = open('293_late_mandatory_training.csv', 'w', newline='')
_293_late_mandatory = csv.writer(_293_late_mandatory_file)
_293_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_293_due_mandatory_file = open('293_due_mandatory_training.csv', 'w', newline='')
_293_due_mandatory = csv.writer(_293_due_mandatory_file)
_293_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_281_late_mandatory_file = open('281_late_mandatory_training.csv', 'w', newline='')
_281_late_mandatory = csv.writer(_281_late_mandatory_file)
_281_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_281_due_mandatory_file = open('281_due_mandatory_training.csv', 'w', newline='')
_281_due_mandatory = csv.writer(_281_due_mandatory_file)
_281_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_277_late_mandatory_file = open('277_late_mandatory_training.csv', 'w', newline='')
_277_late_mandatory = csv.writer(_277_late_mandatory_file)
_277_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_277_due_mandatory_file = open('277_due_mandatory_training.csv', 'w', newline='')
_277_due_mandatory = csv.writer(_277_due_mandatory_file)
_277_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_195_late_mandatory_file = open('195_late_mandatory_training.csv', 'w', newline='')
_195_late_mandatory = csv.writer(_195_late_mandatory_file)
_195_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_195_due_mandatory_file = open('195_due_mandatory_training.csv', 'w', newline='')
_195_due_mandatory = csv.writer(_195_due_mandatory_file)
_195_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_238_late_mandatory_file = open('238_late_mandatory_training.csv', 'w', newline='')
_238_late_mandatory = csv.writer(_238_late_mandatory_file)
_238_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_238_due_mandatory_file = open('238_due_mandatory_training.csv', 'w', newline='')
_238_due_mandatory = csv.writer(_238_due_mandatory_file)
_238_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_206_late_mandatory_file = open('206_late_mandatory_training.csv', 'w', newline='')
_206_late_mandatory = csv.writer(_206_late_mandatory_file)
_206_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_206_due_mandatory_file = open('206_due_mandatory_training.csv', 'w', newline='')
_206_due_mandatory = csv.writer(_206_due_mandatory_file)
_206_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_283_late_mandatory_file = open('283_late_mandatory_training.csv', 'w', newline='')
_283_late_mandatory = csv.writer(_283_late_mandatory_file)
_283_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_283_due_mandatory_file = open('283_due_mandatory_training.csv', 'w', newline='')
_283_due_mandatory = csv.writer(_283_due_mandatory_file)
_283_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_42_late_mandatory_file = open('42_late_mandatory_training.csv', 'w', newline='')
_42_late_mandatory = csv.writer(_42_late_mandatory_file)
_42_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_42_due_mandatory_file = open('42_due_mandatory_training.csv', 'w', newline='')
_42_due_mandatory = csv.writer(_42_due_mandatory_file)
_42_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_95_late_mandatory_file = open('95_late_mandatory_training.csv', 'w', newline='')
_95_late_mandatory = csv.writer(_95_late_mandatory_file)
_95_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_95_due_mandatory_file = open('95_due_mandatory_training.csv', 'w', newline='')
_95_due_mandatory = csv.writer(_95_due_mandatory_file)
_95_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_303_late_mandatory_file = open('303_late_mandatory_training.csv', 'w', newline='')
_303_late_mandatory = csv.writer(_303_late_mandatory_file)
_303_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_303_due_mandatory_file = open('303_due_mandatory_training.csv', 'w', newline='')
_303_due_mandatory = csv.writer(_303_due_mandatory_file)
_303_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_113_late_mandatory_file = open('113_late_mandatory_training.csv', 'w', newline='')
_113_late_mandatory = csv.writer(_113_late_mandatory_file)
_113_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_113_due_mandatory_file = open('113_due_mandatory_training.csv', 'w', newline='')
_113_due_mandatory = csv.writer(_113_due_mandatory_file)
_113_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_218_late_mandatory_file = open('218_late_mandatory_training.csv', 'w', newline='')
_218_late_mandatory = csv.writer(_218_late_mandatory_file)
_218_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_218_due_mandatory_file = open('218_due_mandatory_training.csv', 'w', newline='')
_218_due_mandatory = csv.writer(_218_due_mandatory_file)
_218_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_332_late_mandatory_file = open('332_late_mandatory_training.csv', 'w', newline='')
_332_late_mandatory = csv.writer(_332_late_mandatory_file)
_332_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_332_due_mandatory_file = open('332_due_mandatory_training.csv', 'w', newline='')
_332_due_mandatory = csv.writer(_332_due_mandatory_file)
_332_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#Spitfire

_298_late_mandatory_file = open('298_late_mandatory_training.csv', 'w', newline='')
_298_late_mandatory = csv.writer(_298_late_mandatory_file)
_298_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_298_due_mandatory_file = open('298_due_mandatory_training.csv', 'w', newline='')
_298_due_mandatory = csv.writer(_298_due_mandatory_file)
_298_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_144_late_mandatory_file = open('144_late_mandatory_training.csv', 'w', newline='')
_144_late_mandatory = csv.writer(_144_late_mandatory_file)
_144_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_144_due_mandatory_file = open('144_due_mandatory_training.csv', 'w', newline='')
_144_due_mandatory = csv.writer(_144_due_mandatory_file)
_144_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_34_late_mandatory_file = open('34_late_mandatory_training.csv', 'w', newline='')
_34_late_mandatory = csv.writer(_34_late_mandatory_file)
_34_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_34_due_mandatory_file = open('34_due_mandatory_training.csv', 'w', newline='')
_34_due_mandatory = csv.writer(_34_due_mandatory_file)
_34_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_234_late_mandatory_file = open('234_late_mandatory_training.csv', 'w', newline='')
_234_late_mandatory = csv.writer(_234_late_mandatory_file)
_234_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_234_due_mandatory_file = open('234_due_mandatory_training.csv', 'w', newline='')
_234_due_mandatory = csv.writer(_234_due_mandatory_file)
_234_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_237_late_mandatory_file = open('237_late_mandatory_training.csv', 'w', newline='')
_237_late_mandatory = csv.writer(_237_late_mandatory_file)
_237_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_237_due_mandatory_file = open('237_due_mandatory_training.csv', 'w', newline='')
_237_due_mandatory = csv.writer(_237_due_mandatory_file)
_237_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_126_late_mandatory_file = open('126_late_mandatory_training.csv', 'w', newline='')
_126_late_mandatory = csv.writer(_126_late_mandatory_file)
_126_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_126_due_mandatory_file = open('126_due_mandatory_training.csv', 'w', newline='')
_126_due_mandatory = csv.writer(_126_due_mandatory_file)
_126_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_87_late_mandatory_file = open('87_late_mandatory_training.csv', 'w', newline='')
_87_late_mandatory = csv.writer(_87_late_mandatory_file)
_87_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_87_due_mandatory_file = open('87_due_mandatory_training.csv', 'w', newline='')
_87_due_mandatory = csv.writer(_87_due_mandatory_file)
_87_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_261_late_mandatory_file = open('261_late_mandatory_training.csv', 'w', newline='')
_261_late_mandatory = csv.writer(_261_late_mandatory_file)
_261_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_261_due_mandatory_file = open('261_due_mandatory_training.csv', 'w', newline='')
_261_due_mandatory = csv.writer(_261_due_mandatory_file)
_261_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_118_late_mandatory_file = open('118_late_mandatory_training.csv', 'w', newline='')
_118_late_mandatory = csv.writer(_118_late_mandatory_file)
_118_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_118_due_mandatory_file = open('118_due_mandatory_training.csv', 'w', newline='')
_118_due_mandatory = csv.writer(_118_due_mandatory_file)
_118_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_184_late_mandatory_file = open('184_late_mandatory_training.csv', 'w', newline='')
_184_late_mandatory = csv.writer(_184_late_mandatory_file)
_184_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_184_due_mandatory_file = open('184_due_mandatory_training.csv', 'w', newline='')
_184_due_mandatory = csv.writer(_184_due_mandatory_file)
_184_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_155_late_mandatory_file = open('155_late_mandatory_training.csv', 'w', newline='')
_155_late_mandatory = csv.writer(_155_late_mandatory_file)
_155_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_155_due_mandatory_file = open('155_due_mandatory_training.csv', 'w', newline='')
_155_due_mandatory = csv.writer(_155_due_mandatory_file)
_155_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_211_late_mandatory_file = open('211_late_mandatory_training.csv', 'w', newline='')
_211_late_mandatory = csv.writer(_211_late_mandatory_file)
_211_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_211_due_mandatory_file = open('211_due_mandatory_training.csv', 'w', newline='')
_211_due_mandatory = csv.writer(_211_due_mandatory_file)
_211_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_309_late_mandatory_file = open('309_late_mandatory_training.csv', 'w', newline='')
_309_late_mandatory = csv.writer(_309_late_mandatory_file)
_309_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_309_due_mandatory_file = open('309_due_mandatory_training.csv', 'w', newline='')
_309_due_mandatory = csv.writer(_309_due_mandatory_file)
_309_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_141_late_mandatory_file = open('141_late_mandatory_training.csv', 'w', newline='')
_141_late_mandatory = csv.writer(_141_late_mandatory_file)
_141_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_141_due_mandatory_file = open('141_due_mandatory_training.csv', 'w', newline='')
_141_due_mandatory = csv.writer(_141_due_mandatory_file)
_141_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_305_late_mandatory_file = open('305_late_mandatory_training.csv', 'w', newline='')
_305_late_mandatory = csv.writer(_305_late_mandatory_file)
_305_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_305_due_mandatory_file = open('305_due_mandatory_training.csv', 'w', newline='')
_305_due_mandatory = csv.writer(_305_due_mandatory_file)
_305_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_330_late_mandatory_file = open('330_late_mandatory_training.csv', 'w', newline='')
_330_late_mandatory = csv.writer(_330_late_mandatory_file)
_330_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_330_due_mandatory_file = open('330_due_mandatory_training.csv', 'w', newline='')
_330_due_mandatory = csv.writer(_330_due_mandatory_file)
_330_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_331_late_mandatory_file = open('331_late_mandatory_training.csv', 'w', newline='')
_331_late_mandatory = csv.writer(_331_late_mandatory_file)
_331_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_331_due_mandatory_file = open('331_due_mandatory_training.csv', 'w', newline='')
_331_due_mandatory = csv.writer(_331_due_mandatory_file)
_331_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#SCE

_143_late_mandatory_file = open('143_late_mandatory_training.csv', 'w', newline='')
_143_late_mandatory = csv.writer(_143_late_mandatory_file)
_143_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_143_due_mandatory_file = open('143_due_mandatory_training.csv', 'w', newline='')
_143_due_mandatory = csv.writer(_143_due_mandatory_file)
_143_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_21_late_mandatory_file = open('21_late_mandatory_training.csv', 'w', newline='')
_21_late_mandatory = csv.writer(_21_late_mandatory_file)
_21_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_21_due_mandatory_file = open('21_due_mandatory_training.csv', 'w', newline='')
_21_due_mandatory = csv.writer(_21_due_mandatory_file)
_21_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_197_late_mandatory_file = open('197_late_mandatory_training.csv', 'w', newline='')
_197_late_mandatory = csv.writer(_197_late_mandatory_file)
_197_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_197_due_mandatory_file = open('197_due_mandatory_training.csv', 'w', newline='')
_197_due_mandatory = csv.writer(_197_due_mandatory_file)
_197_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_209_late_mandatory_file = open('209_late_mandatory_training.csv', 'w', newline='')
_209_late_mandatory = csv.writer(_209_late_mandatory_file)
_209_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_209_due_mandatory_file = open('209_due_mandatory_training.csv', 'w', newline='')
_209_due_mandatory = csv.writer(_209_due_mandatory_file)
_209_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_167_late_mandatory_file = open('167_late_mandatory_training.csv', 'w', newline='')
_167_late_mandatory = csv.writer(_167_late_mandatory_file)
_167_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_167_due_mandatory_file = open('167_due_mandatory_training.csv', 'w', newline='')
_167_due_mandatory = csv.writer(_167_due_mandatory_file)
_167_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_235_late_mandatory_file = open('235_late_mandatory_training.csv', 'w', newline='')
_235_late_mandatory = csv.writer(_235_late_mandatory_file)
_235_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_235_due_mandatory_file = open('235_due_mandatory_training.csv', 'w', newline='')
_235_due_mandatory = csv.writer(_235_due_mandatory_file)
_235_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_227_late_mandatory_file = open('227_late_mandatory_training.csv', 'w', newline='')
_227_late_mandatory = csv.writer(_227_late_mandatory_file)
_227_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_227_due_mandatory_file = open('227_due_mandatory_training.csv', 'w', newline='')
_227_due_mandatory = csv.writer(_227_due_mandatory_file)
_227_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_172_late_mandatory_file = open('172_late_mandatory_training.csv', 'w', newline='')
_172_late_mandatory = csv.writer(_172_late_mandatory_file)
_172_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_172_due_mandatory_file = open('172_due_mandatory_training.csv', 'w', newline='')
_172_due_mandatory = csv.writer(_172_due_mandatory_file)
_172_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_257_late_mandatory_file = open('257_late_mandatory_training.csv', 'w', newline='')
_257_late_mandatory = csv.writer(_257_late_mandatory_file)
_257_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_257_due_mandatory_file = open('257_due_mandatory_training.csv', 'w', newline='')
_257_due_mandatory = csv.writer(_257_due_mandatory_file)
_257_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_164_late_mandatory_file = open('164_late_mandatory_training.csv', 'w', newline='')
_164_late_mandatory = csv.writer(_164_late_mandatory_file)
_164_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_164_due_mandatory_file = open('164_due_mandatory_training.csv', 'w', newline='')
_164_due_mandatory = csv.writer(_164_due_mandatory_file)
_164_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_326_late_mandatory_file = open('326_late_mandatory_training.csv', 'w', newline='')
_326_late_mandatory = csv.writer(_326_late_mandatory_file)
_326_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_326_due_mandatory_file = open('326_due_mandatory_training.csv', 'w', newline='')
_326_due_mandatory = csv.writer(_326_due_mandatory_file)
_326_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_102_late_mandatory_file = open('102_late_mandatory_training.csv', 'w', newline='')
_102_late_mandatory = csv.writer(_102_late_mandatory_file)
_102_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_102_due_mandatory_file = open('102_due_mandatory_training.csv', 'w', newline='')
_102_due_mandatory = csv.writer(_102_due_mandatory_file)
_102_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#SCW

_163_late_mandatory_file = open('163_late_mandatory_training.csv', 'w', newline='')
_163_late_mandatory = csv.writer(_163_late_mandatory_file)
_163_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_163_due_mandatory_file = open('163_due_mandatory_training.csv', 'w', newline='')
_163_due_mandatory = csv.writer(_163_due_mandatory_file)
_163_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_31_late_mandatory_file = open('31_late_mandatory_training.csv', 'w', newline='')
_31_late_mandatory = csv.writer(_31_late_mandatory_file)
_31_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_31_due_mandatory_file = open('31_due_mandatory_training.csv', 'w', newline='')
_31_due_mandatory = csv.writer(_31_due_mandatory_file)
_31_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_248_late_mandatory_file = open('248_late_mandatory_training.csv', 'w', newline='')
_248_late_mandatory = csv.writer(_248_late_mandatory_file)
_248_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_248_due_mandatory_file = open('248_due_mandatory_training.csv', 'w', newline='')
_248_due_mandatory = csv.writer(_248_due_mandatory_file)
_248_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_33_late_mandatory_file = open('33_late_mandatory_training.csv', 'w', newline='')
_33_late_mandatory = csv.writer(_33_late_mandatory_file)
_33_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_33_due_mandatory_file = open('33_due_mandatory_training.csv', 'w', newline='')
_33_due_mandatory = csv.writer(_33_due_mandatory_file)
_33_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_13_late_mandatory_file = open('13_late_mandatory_training.csv', 'w', newline='')
_13_late_mandatory = csv.writer(_13_late_mandatory_file)
_13_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_13_due_mandatory_file = open('13_due_mandatory_training.csv', 'w', newline='')
_13_due_mandatory = csv.writer(_13_due_mandatory_file)
_13_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_67_late_mandatory_file = open('67_late_mandatory_training.csv', 'w', newline='')
_67_late_mandatory = csv.writer(_67_late_mandatory_file)
_67_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_67_due_mandatory_file = open('67_due_mandatory_training.csv', 'w', newline='')
_67_due_mandatory = csv.writer(_67_due_mandatory_file)
_67_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_171_late_mandatory_file = open('171_late_mandatory_training.csv', 'w', newline='')
_171_late_mandatory = csv.writer(_171_late_mandatory_file)
_171_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_171_due_mandatory_file = open('171_due_mandatory_training.csv', 'w', newline='')
_171_due_mandatory = csv.writer(_171_due_mandatory_file)
_171_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_242_late_mandatory_file = open('242_late_mandatory_training.csv', 'w', newline='')
_242_late_mandatory = csv.writer(_242_late_mandatory_file)
_242_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_242_due_mandatory_file = open('242_due_mandatory_training.csv', 'w', newline='')
_242_due_mandatory = csv.writer(_242_due_mandatory_file)
_242_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#tame

_25_late_mandatory_file = open('25_late_mandatory_training.csv', 'w', newline='')
_25_late_mandatory = csv.writer(_25_late_mandatory_file)
_25_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_25_due_mandatory_file = open('25_due_mandatory_training.csv', 'w', newline='')
_25_due_mandatory = csv.writer(_25_due_mandatory_file)
_25_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_114_late_mandatory_file = open('114_late_mandatory_training.csv', 'w', newline='')
_114_late_mandatory = csv.writer(_114_late_mandatory_file)
_114_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_114_due_mandatory_file = open('114_due_mandatory_training.csv', 'w', newline='')
_114_due_mandatory = csv.writer(_114_due_mandatory_file)
_114_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_64_late_mandatory_file = open('64_late_mandatory_training.csv', 'w', newline='')
_64_late_mandatory = csv.writer(_64_late_mandatory_file)
_64_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_64_due_mandatory_file = open('64_due_mandatory_training.csv', 'w', newline='')
_64_due_mandatory = csv.writer(_64_due_mandatory_file)
_64_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_236_late_mandatory_file = open('236_late_mandatory_training.csv', 'w', newline='')
_236_late_mandatory = csv.writer(_236_late_mandatory_file)
_236_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_236_due_mandatory_file = open('236_due_mandatory_training.csv', 'w', newline='')
_236_due_mandatory = csv.writer(_236_due_mandatory_file)
_236_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_177_late_mandatory_file = open('177_late_mandatory_training.csv', 'w', newline='')
_177_late_mandatory = csv.writer(_177_late_mandatory_file)
_177_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_177_due_mandatory_file = open('177_due_mandatory_training.csv', 'w', newline='')
_177_due_mandatory = csv.writer(_177_due_mandatory_file)
_177_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_210_late_mandatory_file = open('210_late_mandatory_training.csv', 'w', newline='')
_210_late_mandatory = csv.writer(_210_late_mandatory_file)
_210_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_210_due_mandatory_file = open('210_due_mandatory_training.csv', 'w', newline='')
_210_due_mandatory = csv.writer(_210_due_mandatory_file)
_210_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_244_late_mandatory_file = open('244_late_mandatory_training.csv', 'w', newline='')
_244_late_mandatory = csv.writer(_244_late_mandatory_file)
_244_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_244_due_mandatory_file = open('244_due_mandatory_training.csv', 'w', newline='')
_244_due_mandatory = csv.writer(_244_due_mandatory_file)
_244_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_213_late_mandatory_file = open('213_late_mandatory_training.csv', 'w', newline='')
_213_late_mandatory = csv.writer(_213_late_mandatory_file)
_213_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_213_due_mandatory_file = open('213_due_mandatory_training.csv', 'w', newline='')
_213_due_mandatory = csv.writer(_213_due_mandatory_file)
_213_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_32_late_mandatory_file = open('32_late_mandatory_training.csv', 'w', newline='')
_32_late_mandatory = csv.writer(_32_late_mandatory_file)
_32_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_32_due_mandatory_file = open('32_due_mandatory_training.csv', 'w', newline='')
_32_due_mandatory = csv.writer(_32_due_mandatory_file)
_32_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_5_late_mandatory_file = open('5_late_mandatory_training.csv', 'w', newline='')
_5_late_mandatory = csv.writer(_5_late_mandatory_file)
_5_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_5_due_mandatory_file = open('5_due_mandatory_training.csv', 'w', newline='')
_5_due_mandatory = csv.writer(_5_due_mandatory_file)
_5_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_222_late_mandatory_file = open('222_late_mandatory_training.csv', 'w', newline='')
_222_late_mandatory = csv.writer(_222_late_mandatory_file)
_222_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_222_due_mandatory_file = open('222_due_mandatory_training.csv', 'w', newline='')
_222_due_mandatory = csv.writer(_222_due_mandatory_file)
_222_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_313_late_mandatory_file = open('313_late_mandatory_training.csv', 'w', newline='')
_313_late_mandatory = csv.writer(_313_late_mandatory_file)
_313_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_313_due_mandatory_file = open('313_due_mandatory_training.csv', 'w', newline='')
_313_due_mandatory = csv.writer(_313_due_mandatory_file)
_313_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_327_late_mandatory_file = open('327_late_mandatory_training.csv', 'w', newline='')
_327_late_mandatory = csv.writer(_327_late_mandatory_file)
_327_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_327_due_mandatory_file = open('327_due_mandatory_training.csv', 'w', newline='')
_327_due_mandatory = csv.writer(_327_due_mandatory_file)
_327_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_333_late_mandatory_file = open('333_late_mandatory_training.csv', 'w', newline='')
_333_late_mandatory = csv.writer(_333_late_mandatory_file)
_333_late_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

_333_due_mandatory_file = open('333_due_mandatory_training.csv', 'w', newline='')
_333_due_mandatory = csv.writer(_333_due_mandatory_file)
_333_due_mandatory.writerow(['Membership Number', 'Known_Name', 'Surname', 'E-Mail', 'Telephone', 'Role', 'Line Manager', 'Group', 'District', 'Safety', 'Safeguarding', 'First Aid'])

#Modules
def CVS():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('CVS_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '81st Birmingham (1st West Heath)':
            _81_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])       
        if group_name == '96th Birmingham South (1st Grove)':
            _96_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '192nd Birmingham (2nd Acocks Green)':
            _81_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '24th Birmingham (Manor Farm)':
            _24_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '254th Birmingham (St Peters Church)':
            _254_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '89th Birmingham (1st Hall Green)':
            _89_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '220th Birmingham (St Agnes)':
            _220_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '260th Birmingham':
            _260_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '100th Birmingham (1st Bournville)':
            _100_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '219th Birmingham':
            _219_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '198th Birmingham (1st St.Nicolas)':
            _198_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '232nd Birmingham (Acocks Green)':
            _232_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '258th Birmingham St Annes West Heath':
            _258_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '29th Birmingham (Selly Park)':
            _29_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '279th Birmingham Hall Green Parish':
            _279_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '304th Birmingham MAB':
            _304_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '148th Birmingham (St Dunstans)':
            _148_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '325th Birmingham (Billesley) Scout Group':
            _325_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('CVS_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '81st Birmingham (1st West Heath)':
            _81_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '96th Birmingham South (1st Grove)':
            _96_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '192nd Birmingham (2nd Acocks Green)':
            _81_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '24th Birmingham (Manor Farm)':
            _24_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '254th Birmingham (St Peters Church)':
            _254_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '89th Birmingham (1st Hall Green)':
            _89_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '220th Birmingham (St Agnes)':
            _220_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '260th Birmingham':
            _260_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '100th Birmingham (1st Bournville)':
            _100_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '219th Birmingham':
            _219_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '198th Birmingham (1st St.Nicolas)':
            _198_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '232nd Birmingham (Acocks Green)':
            _232_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '258th Birmingham St Annes West Heath':
            _258_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '29th Birmingham (Selly Park)':
            _29_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '279th Birmingham Hall Green Parish':
            _279_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '304th Birmingham MAB':
            _304_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '148th Birmingham (St Dunstans)':
            _148_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '325th Birmingham (Billesley) Scout Group':
            _325_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  

    #5: Close files

    _81_late_mandatory_file.close()
    _96_late_mandatory_file.close()
    _81_late_mandatory_file.close()
    _24_late_mandatory_file.close()
    _254_late_mandatory_file.close()
    _89_late_mandatory_file.close()
    _220_late_mandatory_file.close()
    _260_late_mandatory_file.close()
    _100_late_mandatory_file.close()
    _219_late_mandatory_file.close()
    _198_late_mandatory_file.close()
    _232_late_mandatory_file.close()
    _258_late_mandatory_file.close()
    _29_late_mandatory_file.close()
    _279_late_mandatory_file.close()
    _304_late_mandatory_file.close()
    _148_late_mandatory_file.close()
    _325_late_mandatory_file.close()

    _81_due_mandatory_file.close()
    _96_due_mandatory_file.close()
    _81_due_mandatory_file.close()
    _24_due_mandatory_file.close()
    _254_due_mandatory_file.close()
    _89_due_mandatory_file.close()
    _220_due_mandatory_file.close()
    _260_due_mandatory_file.close()
    _100_due_mandatory_file.close()
    _219_due_mandatory_file.close()
    _198_due_mandatory_file.close()
    _232_due_mandatory_file.close()
    _258_due_mandatory_file.close()
    _29_due_mandatory_file.close()
    _279_due_mandatory_file.close()
    _304_due_mandatory_file.close()
    _148_due_mandatory_file.close()
    _325_due_mandatory_file.close()
    print("CVS done!")

def rea():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('rea_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == "74th Birmingham (St Germain's)":
            _74_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '191st Birmingham (Phoenix Scout Group)':
            _191_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '145th Birmingham (Victoria School)':
            _145_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '108th Birmingham (1st Weoley Hill)':
            _108_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '169th Birmingham West (1st Quinton)':
            _169_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '293rd Birmingham (St Faith and St Laurence)':
            _293_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "281st Birmingham (St David's)":
            _281_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '277th Birmingham (Beacon)':
            _277_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '195th Birmingham (St.Johns Longbridge)':
            _195_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '238th Birmingham (Northfield Methodist)':
            _238_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '206th Birmingham (St Laurence)':
            _206_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '283rd Birmingham (Eagle)':
            _283_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '42nd Birmingham 1st Kings Norton':
            _42_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '95th Birmingham (Harborne, St Peters)':
            _95_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '303rd Birmingham (St. Josephs and St. Helens)':
            _303_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '113th Birmingham (1st Ariel)':
            _113_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '218th Birmingham (Woodgate Pioneers)':
            _218_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '332nd Birmingham (Selly Oak Trust School)':
            _332_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  

    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('rea_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == "74th Birmingham (St Germain's)":
            _74_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '191st Birmingham (Phoenix Scout Group)':
            _191_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '145th Birmingham (Victoria School)':
            _145_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '108th Birmingham (1st Weoley Hill)':
            _108_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '169th Birmingham West (1st Quinton)':
            _169_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '293rd Birmingham (St Faith and St Laurence)':
            _293_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "281st Birmingham (St David's)":
            _281_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '277th Birmingham (Beacon)':
            _277_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '195th Birmingham (St.Johns Longbridge)':
            _195_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '238th Birmingham (Northfield Methodist)':
            _238_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '206th Birmingham (St Laurence)':
            _206_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '283rd Birmingham (Eagle)':
            _283_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '42nd Birmingham 1st Kings Norton':
            _42_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '95th Birmingham (Harborne, St Peters)':
            _95_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '303rd Birmingham (St. Josephs and St. Helens)':
            _303_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '113th Birmingham (1st Ariel)':
            _113_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '218th Birmingham (Woodgate Pioneers)':
            _218_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '332nd Birmingham (Selly Oak Trust School)':
            _332_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  

    #5: Close files

    _74_late_mandatory_file.close()
    _191_late_mandatory_file.close()
    _145_late_mandatory_file.close()
    _108_late_mandatory_file.close()
    _169_late_mandatory_file.close()
    _293_late_mandatory_file.close()
    _281_late_mandatory_file.close()
    _277_late_mandatory_file.close()
    _195_late_mandatory_file.close()
    _238_late_mandatory_file.close()
    _206_late_mandatory_file.close()
    _283_late_mandatory_file.close()
    _42_late_mandatory_file.close()
    _95_late_mandatory_file.close()
    _303_late_mandatory_file.close()
    _113_late_mandatory_file.close()
    _218_late_mandatory_file.close()
    _332_late_mandatory_file.close()

    _74_due_mandatory_file.close()
    _191_due_mandatory_file.close()
    _145_due_mandatory_file.close()
    _108_due_mandatory_file.close()
    _169_due_mandatory_file.close()
    _293_due_mandatory_file.close()
    _281_due_mandatory_file.close()
    _277_due_mandatory_file.close()
    _195_due_mandatory_file.close()
    _238_due_mandatory_file.close()
    _206_due_mandatory_file.close()
    _283_due_mandatory_file.close()
    _42_due_mandatory_file.close()
    _95_due_mandatory_file.close()
    _303_due_mandatory_file.close()
    _113_due_mandatory_file.close()
    _218_due_mandatory_file.close()
    _332_due_mandatory_file.close()
    print("rea done!")

def spitfire():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('spitfire_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '298th Birmingham Silvermere Sheldon':
            _298_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '1st Sheldon (144th Birmingham)':
            _144_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '34th Birmingham (Ward End)':
            _34_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '234th Birmingham (1st Castle Vale)':
            _234_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '237th Birmingham 1st Castle Bromwich':
            _237_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '126th Birmingham 1st Hodge Hill S.S.Philip & James':
            _126_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '87th Birmingham (Bierton)':
            _87_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '261st Birmingham (St Edburghas Yardley)':
            _261_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '118th Birmingham (1st Nansen)':
            _118_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '184th Birmingham (1st Kingshurst)':
            _184_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '155th Birmingham (1st Tile Cross)/229th Birmingham (1st Yorks Wood)':
            _155_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '211th Birmingham (St Annes)':
            _211_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '309th Birmingham':
            _309_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '141st Birmingham 1st Yardley':
            _141_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '305th Birmingham Somerville':
            _305_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '330th Birmingham (The Pillars Academy Hodge Hill) Scout Group':
            _330_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '331st Birmingham (Al Hijrah Masjid)':
            _331_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('spitfire_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == "298th Birmingham Silvermere Sheldon":
            _298_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '1st Sheldon (144th Birmingham)':
            _144_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '34th Birmingham (Ward End)':
            _34_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '234th Birmingham (1st Castle Vale)':
            _234_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '237th Birmingham 1st Castle Bromwich':
            _237_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '126th Birmingham 1st Hodge Hill S.S.Philip & James':
            _126_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '87th Birmingham (Bierton)':
            _87_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '261st Birmingham (St Edburghas Yardley)':
            _261_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '118th Birmingham (1st Nansen)':
            _118_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '184th Birmingham (1st Kingshurst)':
            _184_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '155th Birmingham (1st Tile Cross)/229th Birmingham (1st Yorks Wood)':
            _155_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '211th Birmingham (St Annes)':
            _211_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '309th Birmingham':
            _309_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '141st Birmingham 1st Yardley':
            _141_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '305th Birmingham Somerville':
            _305_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '330th Birmingham (The Pillars Academy Hodge Hill) Scout Group':
            _330_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '331st Birmingham (Al Hijrah Masjid)':
            _331_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #5: Close files

    _298_late_mandatory_file.close()
    _144_late_mandatory_file.close()
    _34_late_mandatory_file.close()
    _234_late_mandatory_file.close()
    _237_late_mandatory_file.close()
    _126_late_mandatory_file.close()
    _87_late_mandatory_file.close()
    _261_late_mandatory_file.close()
    _118_late_mandatory_file.close()
    _184_late_mandatory_file.close()
    _155_late_mandatory_file.close()
    _211_late_mandatory_file.close()
    _309_late_mandatory_file.close()
    _141_late_mandatory_file.close()
    _305_late_mandatory_file.close()
    _330_late_mandatory_file.close()
    _331_late_mandatory_file.close()
    
    _298_due_mandatory_file.close()
    _144_due_mandatory_file.close()
    _34_due_mandatory_file.close()
    _234_due_mandatory_file.close()
    _237_due_mandatory_file.close()
    _126_due_mandatory_file.close()
    _87_due_mandatory_file.close()
    _261_due_mandatory_file.close()
    _118_due_mandatory_file.close()
    _184_due_mandatory_file.close()
    _155_due_mandatory_file.close()
    _211_due_mandatory_file.close()
    _309_due_mandatory_file.close()
    _141_due_mandatory_file.close()
    _305_due_mandatory_file.close()
    _330_due_mandatory_file.close()
    _331_due_mandatory_file.close()
    
    print("spitfire done!")

def SCE():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('SCE_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '143rd Birmingham {St James Hill}':
            _143_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '21st Birmingham (8th Sutton Coldfield East) - U.R.C.':
            _21_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '197th Birmingham (St.Chads Sutton Coldfield)':
            _197_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '17th Sutton Coldfield (All Saints) 209th Birmingham':
            _209_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '167th Birmingham (South Parade Methodist)':
            _167_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '235th Birmingham (St Peters Maney)':
            _235_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '227th Birmingham (2nd Wylde Green)':
            _227_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '172nd Birmingham Four Oaks Methodist':
            _172_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '257th Birmingham 1st Little Sutton Baptist':
            _257_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '164th Birmingham Holy Trinity Sutton Coldfield':
            _164_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '326th Birmingham/12th Sutton Coldfield':
            _326_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '19th Sutton Coldfield East (Falcon Lodge), 102nd Birmingham':
            _102_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
   
    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('SCE_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '143rd Birmingham {St James Hill}':
            _143_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '21st Birmingham (8th Sutton Coldfield East) - U.R.C.':
            _21_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '197th Birmingham (St.Chads Sutton Coldfield)':
            _197_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '17th Sutton Coldfield (All Saints) 209th Birmingham':
            _209_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '167th Birmingham (South Parade Methodist)':
            _167_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '235th Birmingham (St Peters Maney)':
            _235_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '227th Birmingham (2nd Wylde Green)':
            _227_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '172nd Birmingham Four Oaks Methodist':
            _172_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '257th Birmingham 1st Little Sutton Baptist':
            _257_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '164th Birmingham Holy Trinity Sutton Coldfield':
            _164_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '326th Birmingham/12th Sutton Coldfield':
            _326_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '19th Sutton Coldfield East (Falcon Lodge), 102nd Birmingham':
            _102_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #5: Close files

    _143_late_mandatory_file.close()
    _21_late_mandatory_file.close()
    _197_late_mandatory_file.close()
    _209_late_mandatory_file.close()
    _167_late_mandatory_file.close()
    _235_late_mandatory_file.close()
    _227_late_mandatory_file.close()
    _172_late_mandatory_file.close()
    _257_late_mandatory_file.close()
    _164_late_mandatory_file.close()
    _326_late_mandatory_file.close()
    _102_late_mandatory_file.close()
    
    _143_due_mandatory_file.close()
    _21_due_mandatory_file.close()
    _197_due_mandatory_file.close()
    _209_due_mandatory_file.close()
    _167_due_mandatory_file.close()
    _235_due_mandatory_file.close()
    _227_due_mandatory_file.close()
    _172_due_mandatory_file.close()
    _257_due_mandatory_file.close()
    _164_due_mandatory_file.close()
    _326_due_mandatory_file.close()
    _102_due_mandatory_file.close()
    print("SCE done!")

def SCW():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('SCW_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '163rd Birmingham (1st Wylde Green)':
            _163_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '31st Sutton Coldfield (3rd Streetly)':
            _31_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '248th Birmingham (Wylde Green URC)':
            _248_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '33rd Birmingham (33rd Sutton Coldfield, 1st Bannersgate) Scout Group':
            _33_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '13th Birmingham (1st Streetly)':
            _13_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "67th Birmingham (1st Boldmere) St.Michael's":
            _67_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '171st Birmingham 10th Sutton Coldfield (Sea)':
            _171_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '242nd Birmingham 2nd Streetley':
            _242_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('SCW_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '163rd Birmingham (1st Wylde Green)':
            _163_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '31st Sutton Coldfield (3rd Streetly)':
            _31_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '248th Birmingham (Wylde Green URC)':
            _248_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '33rd Birmingham (33rd Sutton Coldfield, 1st Bannersgate) Scout Group':
            _33_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '13th Birmingham (1st Streetly)':
            _13_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "67th Birmingham (1st Boldmere) St.Michael's":
            _67_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '171st Birmingham 10th Sutton Coldfield (Sea)':
            _171_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '242nd Birmingham 2nd Streetley':
            _242_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #5: Close files

    _163_late_mandatory_file.close()
    _31_late_mandatory_file.close()
    _248_late_mandatory_file.close()
    _33_late_mandatory_file.close()
    _13_late_mandatory_file.close()
    _67_late_mandatory_file.close()
    _171_late_mandatory_file.close()
    _242_late_mandatory_file.close()
    
    _163_due_mandatory_file.close()
    _31_due_mandatory_file.close()
    _248_due_mandatory_file.close()
    _33_due_mandatory_file.close()
    _13_due_mandatory_file.close()
    _67_due_mandatory_file.close()
    _171_due_mandatory_file.close()
    _242_due_mandatory_file.close()
    print("SCW done!")

def tame():
    #1. Open the file
    file_name = str(Path.cwd()) + '/' + str('tame_late_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #2. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '25th Birmingham (1st Beeches)':
            _25_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "114th Birmingham (St Paul's Hamstead)":
            _114_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '64th Birmingham':
            _64_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '236th Birmingham (St.Johns Perry Barr)':
            _236_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '177th Birmingham (Erdington Methodist) Scout Group':
            _177_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '210th Birmingham Pype Hayes Congregational':
            _210_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '244th Birmingham (Holy Name)':
            _244_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '213th Birmingham (Kingstanding) Scout Group':
            _213_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '32nd Birmingham (Methodist Church Perry Hall)':
            _32_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '5th Birmingham (Erdington All Saints)':
            _5_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '222nd Birmingham (Wilson Stuart)':
            _222_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '313th Birmingham (Sahibzadas Sikh)':
            _313_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '327th Birmingham (As-Suffa) Scout Group':
            _327_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '333rd Birmingham Masjid Al Falaah (Maf)':
            _333_late_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #3. Open the file
    file_name = str(Path.cwd()) + '/' + str('tame_due_mandatory_training.csv')
    input_file = open(file_name) #assumes file is in working directory
    #Create a list using the CSV file
    input_data_reader = csv.reader(input_file)
    input_data = list(input_data_reader)

    #4. Process the data
    for x in range(len(input_data)):
        group_name = input_data[x][7]
        if group_name == '25th Birmingham (1st Beeches)':
            _25_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == "114th Birmingham (St Paul's Hamstead)":
            _114_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '64th Birmingham':
            _64_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '236th Birmingham (St.Johns Perry Barr)':
            _236_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '177th Birmingham (Erdington Methodist) Scout Group':
            _177_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '210th Birmingham Pype Hayes Congregational':
            _210_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '244th Birmingham (Holy Name)':
            _244_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '213th Birmingham (Kingstanding) Scout Group':
            _213_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '32nd Birmingham (Methodist Church Perry Hall)':
            _32_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '5th Birmingham (Erdington All Saints)':
            _5_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '222nd Birmingham (Wilson Stuart)':
            _222_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '313th Birmingham (Sahibzadas Sikh)':
            _313_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '327th Birmingham (As-Suffa) Scout Group':
            _327_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        if group_name == '333rd Birmingham Masjid Al Falaah (Maf)':
            _333_due_mandatory.writerow([input_data[x][0], input_data[x][1], input_data[x][2], input_data[x][3], input_data[x][4], input_data[x][5], input_data[x][6], input_data[x][7], input_data[x][8], input_data[x][9], input_data[x][10], input_data[x][11]])  
        
    #5: Close files

    _25_late_mandatory_file.close()
    _114_late_mandatory_file.close()
    _64_late_mandatory_file.close()
    _236_late_mandatory_file.close()
    _177_late_mandatory_file.close()
    _210_late_mandatory_file.close()
    _244_late_mandatory_file.close()
    _213_late_mandatory_file.close()
    _32_late_mandatory_file.close()
    _5_late_mandatory_file.close()
    _222_late_mandatory_file.close()
    _313_late_mandatory_file.close()
    _327_late_mandatory_file.close()
    _333_late_mandatory_file.close()
    
    _25_due_mandatory_file.close()
    _114_due_mandatory_file.close()
    _64_due_mandatory_file.close()
    _236_due_mandatory_file.close()
    _177_due_mandatory_file.close()
    _210_due_mandatory_file.close()
    _244_due_mandatory_file.close()
    _213_due_mandatory_file.close()
    _32_due_mandatory_file.close()
    _5_due_mandatory_file.close()
    _222_due_mandatory_file.close()
    _313_due_mandatory_file.close()
    _327_due_mandatory_file.close()
    _333_due_mandatory_file.close()
    print("tame done!")

#Program
CVS()
rea()
spitfire()
SCE()
SCW()
tame()